@@ -72,10 +72,18 @@ memes = [
     Meme("charpic", charpic, ("字符画",)),
     Meme("mywife", mywife, ("这是我的老婆",), r"这是(?P<ta>\S+)的(?P<name>\S+)"),
     Meme("walnutpad", walnutpad, ("胡桃平板",)),
+    Meme("walnut_zoom", walnut_zoom, ("胡桃放大",)),
     Meme("teach", teach, ("讲课", "敲黑板")),
     Meme("addition", addition, ("上瘾", "毒瘾发作")),
     Meme("gun", gun, ("手枪",)),
     Meme("blood_pressure", blood_pressure, ("高血压",)),
     Meme("read_book", read_book, ("看书",)),
     Meme("call_110", call_110, ("遇到困难请拨打",)),
+    Meme("confuse", confuse, ("迷惑",)),
+    Meme("hit_screen", hit_screen, ("打穿", "打穿屏幕"), r"打穿(?:屏幕)?"),
+    Meme("fencing", fencing, ("击剑", "🤺")),
+    Meme("hug_leg", hug_leg, ("抱大腿",)),
+    Meme("tankuku_holdsign", tankuku_holdsign, ("唐可可举牌",)),
+    Meme("no_response", no_response, ("无响应",)),
+    Meme("hold_tight", hold_tight, ("抱紧",)),
 ]
